@ECHO OFF
ECHO DP============== Start of DATAPROP batch file ================
REM
REM ----check at least one input argument; if not, terminate
REM
IF NOT %1.==. GOTO ARGOK
ECHO   Run model DATAPROP with 1 to n input files as required.
ECHO   Parameters should be entered as follows :-
ECHO    1 to n-1  input files to be concatenated, with file names
ECHO              of the form FILENAME.EXT
ECHO    n         identifier for this run, with file name
ECHO              of the form FILENAME     (N.B. NO EXTENSION)
ECHO              (system assumes extension .DPI, and uses/creates
ECHO              (files with this name and various extensions).
ECHO    if n=1    the file must already exist with the extension .DPI,
ECHO              but the extension must not be included.
ECHO    if n=2    the first file must already exist with its specified
ECHO              extension, and the file will be copied to the
ECHO              second file (system assumes extension .DPI).
ECHO    else      n-1 files must already exist with their specified
ECHO              extensions, and they will be concatenated and copied
ECHO              to the n'th file (system assumes extension .DPI).
ECHO   The file SKELETON.DPI can be copied from %HGSYSTEM%\STINPUT as a
ECHO   template for an input data file *.DPI.
GOTO EXIT
:ARGOK
REM
REM ----SHIFT eliminates first argument and moves all others down one
REM
SHIFT
REM
REM ----check if only one input argument specified
REM
IF NOT %1.==. GOTO NUMARGS
REM
REM ----one argument; check if the input file exists
REM ----if yes, check data dictionary; if not, terminate
REM
IF EXIST %0.DPI GOTO CHECKDD
ECHO DATAPROP - Input file %0.DPI does not exist - program terminated
GOTO EXIT
:NUMARGS
REM
REM ----check if only two input arguments specified
REM
IF NOT %2.==. GOTO CONCAT
REM
REM ----two arguments; check if first file exists; if not, terminate
REM
IF EXIST %0 GOTO COPY1
ECHO DATAPROP - Input file %0 does not exist - program terminated
GOTO EXIT
:COPY1
REM
REM ----copy file, do not concatenate, check data dictionary
REM
copy /b %0 %1.DPI > NUL:
SHIFT
GOTO CHECKDD
:CONCAT
REM
REM ----more than two arguments; create CONCAT key in temporary file
REM
ECHO = CONCAT == > $CONCAT$.DPI
:CHECKN
REM
REM ----check if input file exists; if not, terminate
REM
IF EXIST %0 GOTO COPYN
ECHO DATAPROP - Input file %0 does not exist - program terminated
IF EXIST $CONCAT$.DPI DEL $CONCAT$.DPI
GOTO EXIT
:COPYN
REM
REM ----copy input file at end of temporary file
REM
copy /b $CONCAT$.DPI+%0 > NUL:
REM
REM ----is there another file to concatenate?
REM
SHIFT
IF NOT %1.==. GOTO CHECKN
REM
REM ----no more files to concatenate; copy to final file
REM
copy /b $CONCAT$.DPI %0.DPI > NUL:
IF EXIST $CONCAT$.DPI DEL $CONCAT$.DPI
:CHECKDD
REM
REM ----check if preprocessed data dictionary exists; if not, terminate
REM
IF EXIST %HGSYSTEM%\DICT.DPD GOTO DICTOK
ECHO DICT.DPD data dictionary does not exist - program terminated
GOTO EXIT
:DICTOK
REM
REM ----delete all files which might be generated during DATAPROP run
REM
IF EXIST %0.DPE DEL %0.DPE
IF EXIST %0.DPR DEL %0.DPR
IF EXIST %0.APL DEL %0.APL
IF EXIST %0.SPL DEL %0.SPL
IF EXIST %0.LPL DEL %0.LPL
IF EXIST %0.HBL DEL %0.HBL
IF EXIST %0.HSL DEL %0.HSL
IF EXIST %0.HTL DEL %0.HTL
REM
ECHO Input validation is in progress
REM
REM ----make a copy of the free-format input file
REM
copy /b %0.DPI %0.TMI >NUL:
REM
REM ---- copy name of analysis to file (to set file names in FFMAIN)
REM
ECHO %0 > HGSYST$$.TIT
ECHO DPI >> HGSYST$$.TIT
ECHO %HGSYSTEM%\DICT.DPD >> HGSYST$$.TIT
REM Input: HGSYST$$.TIT, %HGSYSTEM%\DICT.DPD, %0.TMI
REM Output: %0.DPI, %0.DPF, %0.DPU
REM         %0.TME (in case of errors)
%HGSYSTEM%\FFMAIN 
REM
REM ----erase temporary files
REM
IF EXIST HGSYST$$.TIT DEL HGSYST$$.TIT
IF EXIST %0.TMI DEL %0.TMI
IF EXIST %0.DPF DEL %0.DPF
REM
REM ----check if error file exists
REM
IF EXIST %0.DPE GOTO DPERR
IF NOT EXIST %0.TME GOTO FFOK
ECHO Input errors exist - check input file - program terminated
IF EXIST %0.TME DEL %0.TME
IF EXIST %0.DPU DEL %0.DPU
GOTO EXIT
:FFOK
REM
REM ----check if unformatted input file exists; if not, terminate
REM
IF EXIST %0.DPU GOTO UNFOK
ECHO Unformatted input file not available - program terminated
GOTO EXIT
:UNFOK
ECHO DATAPROP calculations are being performed
REM
REM ---- copy name of analysis to file (to set file names in DPMAIN)
REM
ECHO %0 > HGSYST$$.TIT
ECHO DPI >> HGSYST$$.TIT
ECHO %HGSYSTEM%\DATAPROP.DPD >> HGSYST$$.TIT
REM  Input: HGSYST$$.TIT, %0.DPU, DATAPROP.DPD
REM  Output: %0.DPR
REM          %0.APL (if no HF), %0.HBL, %0.HSL, %0.HTL, %0.SPL (link files)
REM          %0.DPE (in case of errors), %0.LPL (no HF)

 %HGSYSTEM%\DPMAIN 

rem run77 d:\dataprop\dpmain.exe /break

REM
REM ----erase temporary files
REM
IF EXIST HGSYST$$.TIT DEL HGSYST$$.TIT
IF EXIST %0.DPU DEL %0.DPU
IF EXIST %0.DPE GOTO DPERR
GOTO DPCONT
:DPERR
ECHO ERRORS have been found during DATAPROP run
ECHO See the file %0.DPE for list of errors
ECHO DP-----------------------------------------------------------
:DPCONT
ECHO End of DATAPROP
IF EXIST %0.DPR ECHO Output in file %0.DPR
IF EXIST %0.APL ECHO AEROPLUME input data stored in file %0.APL
IF EXIST %0.SPL ECHO SPILL input data stored in file %0.SPL
IF EXIST %0.LPL ECHO LPOOL input data stored in file %0.LPL
IF EXIST %0.HBL ECHO HEGABOX input data stored in file %0.HBL
IF EXIST %0.HSL ECHO HEGADAS-S input data stored in file %0.HSL
IF EXIST %0.HTL ECHO HEGADAS-T input data stored in file %0.HTL
:EXIT
ECHO DP============== End   of DATAPROP batch file ================
