@ECHO OFF
ECHO HT============== Start of HEGADAS-T batch file ================
REM Modified by Steve Richardson     12/96
REM
REM Set the environment variable to the shared drive

REM
REM ----check at least one input argument; if not, terminate
REM
IF NOT %1.==. GOTO ARGOK
ECHO   Run model HEGADAS-T with 1 to n input files as required.
ECHO   Parameters should be entered as follows :-
ECHO    1 to n-1  input files to be concatenated, with file names
ECHO              of the form FILENAME.EXT
ECHO    n         identifier for this run, with file name
ECHO              of the form FILENAME     (N.B. NO EXTENSION)
ECHO              (system assumes extension .HTI, and uses/creates
ECHO              (files with this name and various extensions).
ECHO    if n=1    the file must already exist with the extension .HTI,
ECHO              but the extension must not be included.
ECHO    if n=2    the first file must already exist with its specified
ECHO              extension, and the file will be copied to the
ECHO              second file (system assumes extension .HTI).
ECHO    else      n-1 files must already exist with their specified
ECHO              extensions, and they will be concatenated and copied
ECHO              to the n'th file (system assumes extension .HTI).
ECHO   One of the four basic HEGADAS-T input files STPOOLNO.HTI,
ECHO   STBRKNO.HTI, STPOOLHF.HTI, STBRKHF.HTI can be copied from
ECHO   %HGSYSTEM%\STINPUT as a template for an input data file *.HTI.
GOTO EXIT
:ARGOK
REM
REM ----SHIFT eliminates first argument and moves all others down one
REM
SHIFT
REM
REM ----check if only one input argument specified
REM
IF NOT %1.==. GOTO NUMARGS
REM
REM ----one argument; check if the input file exists
REM ----if yes, check data dictionary; if not, terminate
REM
IF EXIST %0.HTI GOTO CHECKDD
ECHO HEGADAST - Input file %0.HTI does not exist - program terminated
GOTO EXIT
:NUMARGS
REM
REM ----check if only two input arguments specified
REM
IF NOT %2.==. GOTO CONCAT
REM
REM ----two arguments; check if first file exists; if not, terminate
REM
IF EXIST %0 GOTO COPY1
ECHO HEGADAST - Input file %0 does not exist - program terminated
GOTO EXIT
:COPY1
REM
REM ----copy file, do not concatenate, check data dictionary
REM
copy /b %0 %1.HTI > NUL:
SHIFT
GOTO CHECKDD
:CONCAT
REM
REM ----more than two arguments; create CONCAT key in temporary file
REM
ECHO = CONCAT == > $CONCAT$.HTI
:CHECKN
REM
REM ----check if input file exists; if not, terminate
REM
IF EXIST %0 GOTO COPYN
ECHO HEGADAST - Input file %0 does not exist - program terminated
IF EXIST $CONCAT$.HTI DEL $CONCAT$.HTI
GOTO EXIT
:COPYN
REM
REM ----copy input file at end of temporary file
REM
copy /b $CONCAT$.HTI+%0 > NUL:
REM
REM ----is there another file to concatenate?
REM
SHIFT
IF NOT %1.==. GOTO CHECKN
REM
REM ----no more files to concatenate; copy to final file
REM
copy /b $CONCAT$.HTI %0.HTI > NUL:
IF EXIST $CONCAT$.HTI DEL $CONCAT$.HTI
:CHECKDD
REM
REM ----check if preprocessed data dictionary exists; if not, terminate
REM
IF EXIST %HGSYSTEM%\DICT.HTD GOTO DICTOK
ECHO DICT.HTD data dictionary does not exist - program terminated
GOTO EXIT
:DICTOK
REM
REM ----delete all files which might be generated during HEGADAST run
REM
IF EXIST %0.HTE DEL %0.HTE
IF EXIST %0.HTR DEL %0.HTR
IF EXIST %0.HT1 DEL %0.HT1
IF EXIST %0.HT2 DEL %0.HT2
IF EXIST %0.HTM DEL %0.HTM
REM
ECHO Input validation is in progress
REM
REM ----make a copy of the free-format input file
REM
copy /b %0.HTI %0.TMI >NUL:
REM
REM ---- copy name of analysis to file (to set file names in FFMAIN)
REM
ECHO %0 > HGSYST$$.TIT
ECHO HTI >> HGSYST$$.TIT
ECHO %HGSYSTEM%\DICT.HTD >> HGSYST$$.TIT
REM Input: HGSYST$$.TIT, %HGSYSTEM%\DICT.HTD, %0.TMI
REM Output: %0.HTI, %0.HTF, %0.HTU
REM         %0.TME (in case of errors)
%HGSYSTEM%\FFMAIN 
REM
REM ----erase temporary files
REM
IF EXIST HGSYST$$.TIT DEL HGSYST$$.TIT
IF EXIST %0.TMI DEL %0.TMI
IF EXIST %0.HTF DEL %0.HTF
REM
REM ----check if error file exists
REM
IF EXIST %0.HTE GOTO HTERR
IF NOT EXIST %0.TME GOTO FFOK
ECHO Input errors exist - check input file - program terminated
IF EXIST %0.TME DEL %0.TME
IF EXIST %0.HTU DEL %0.HTU
GOTO EXIT
:FFOK
REM
REM ----check if unformatted input file exists; if not, terminate
REM
IF EXIST %0.HTU GOTO UNFOK
ECHO Unformatted input file not available - program terminated
GOTO EXIT
:UNFOK
ECHO HEGADAS-T calculations are being performed
REM
REM ---- copy name of analysis to file (to set file names in HTMAIN)
REM
ECHO %0 > HGSYST$$.TIT
REM Input: HGSYST$$.TIT, %0.HTU
REM Output: %0.HTR, %0.HTM, %0.HT1 (if ICNT.GT.0), %0.HT2 (PRTOBS=1)
REM         %0.HTE (in case of errors)

 %HGSYSTEM%\HTMAIN 

REM
REM ----erase temporary files
REM
IF EXIST HGSYST$$.TIT DEL HGSYST$$.TIT
IF EXIST %0.HTU DEL %0.HTU
IF EXIST %0.HTE GOTO HTERR
GOTO HTCONT
:HTERR
ECHO ERRORS have been found during HEGADAS-T run
ECHO See the file %0.HTE for list of errors
ECHO HT--------------------------------------------------------
:HTCONT
ECHO End of HEGADAS-T
IF EXIST %0.HTR ECHO Output in file %0.HTR
IF EXIST %0.HT1 ECHO Isoconcentration and cumulative cloud data in file %0.HT1
IF EXIST %0.HT2 ECHO Observer-dispersion data in file %0.HT2
IF EXIST %0.HTM ECHO Input data for post-processor POSTHT in binary file %0.HTM
:EXIT
ECHO HT============== End   of HEGADAS-T batch file ================
