@ECHO OFF
REM Modified 10/92 (Lourens Post)
REM Modified by Steve Richardson     12/96
REM
REM Set the environment variable to the shared drive

ECHO HP============== Start of HFPLUME batch file ================
REM
REM ----check at least one input argument; if not, terminate
REM
IF NOT %1.==. GOTO ARGOK
ECHO   Run model HFPLUME with 1 to n input files as required.
ECHO   Parameters should be entered as follows :-
ECHO    1 to n-1  input files to be concatenated, with file names
ECHO              of the form FILENAME.EXT
ECHO    n         identifier for this run, with file name
ECHO              of the form FILENAME     (N.B. NO EXTENSION)
ECHO              (system assumes extension .HPI, and uses/creates
ECHO              (files with this name and various extensions).
ECHO    if n=1    the file must already exist with the extension .HPI,
ECHO              but the extension must not be included.
ECHO    if n=2    the first file must already exist with its specified
ECHO              extension, and the file will be copied to the
ECHO              second file (system assumes extension .HPI).
ECHO    else      n-1 files must already exist with their specified
ECHO              extensions, and they will be concatenated and copied
ECHO              to the n'th file (system assumes extension .HPI).
ECHO   The file SKELETON.HPI can be copied from %HGSYSTEM%\STINPUT as a
ECHO   template for an input data file *.HPI.
GOTO EXIT
:ARGOK
REM
REM ----SHIFT eliminates first argument and moves all others down one
REM
SHIFT
REM
REM ----check if only one input argument specified
REM
IF NOT %1.==. GOTO NUMARGS
REM
REM ----one argument; check if the input file exists
REM ----if yes, check data dictionary; if not, terminate
REM
IF EXIST %0.HPI GOTO CHECKDD
ECHO HFPLUME - Input file %0.HPI does not exist - program terminated
GOTO EXIT
:NUMARGS
REM
REM ----check if only two input arguments specified
REM
IF NOT %2.==. GOTO CONCAT
REM
REM ----two arguments; check if first file exists; if not, terminate
REM
IF EXIST %0 GOTO COPY1
ECHO HFPLUME - Input file %0 does not exist - program terminated
GOTO EXIT
:COPY1
REM
REM ----copy file, do not concatenate, check data dictionary
REM
copy /b %0 %1.HPI > NUL:
SHIFT
GOTO CHECKDD
:CONCAT
REM
REM ----more than two arguments; create CONCAT key in temporary file
REM
ECHO = CONCAT == > $CONCAT$.HPI
:CHECKN
REM
REM ----check if input file exists; if not, terminate
REM
IF EXIST %0 GOTO COPYN
ECHO HFPLUME - Input file %0 does not exist - program terminated
IF EXIST $CONCAT$.HPI DEL $CONCAT$.HPI
GOTO EXIT
:COPYN
REM
REM ----copy input file at end of temporary file
REM
copy /b $CONCAT$.HPI+%0 > NUL:
REM
REM ----is there another file to concatenate?
REM
SHIFT
IF NOT %1.==. GOTO CHECKN
REM
REM ----no more files to concatenate; copy to final file
REM
copy /b $CONCAT$.HPI %0.HPI > NUL:
IF EXIST $CONCAT$.HPI DEL $CONCAT$.HPI
:CHECKDD
REM
REM ----check if preprocessed data dictionary exists; if not, terminate
REM
IF EXIST %HGSYSTEM%\DICT.HPD GOTO DICTOK
ECHO DICT.HPD data dictionary does not exist - program terminated
GOTO EXIT
:DICTOK
REM
REM ----delete all files which might be generated during previous HFPLUME run
REM
IF EXIST %0.HPE DEL %0.HPE >NUL:
IF EXIST %0.HPD DEL %0.HPD >NUL:
IF EXIST %0.HPW DEL %0.HPW >NUL:
IF EXIST %0.HPR DEL %0.HPR >NUL:
IF EXIST %0.HP1 DEL %0.HP1 >NUL:
IF EXIST %0.HP2 DEL %0.HP2 >NUL:
IF EXIST %0.HPZ DEL %0.HPZ >NUL:
IF EXIST %0.HPM DEL %0.HPM >NUL:
IF EXIST %0.HPN DEL %0.HPN >NUL:
IF EXIST %0.PGL DEL %0.PGL >NUL:
IF EXIST %0.HSL DEL %0.HSL >NUL:
IF EXIST %0.HTL DEL %0.HTL >NUL:
REM
ECHO Input validation is in progress
REM
REM ----make a copy of the free-format input file
REM
copy /b %0.HPI %0.TMI >NUL:
REM
REM ---- copy name of analysis to file (to set file names in FFMAIN)
REM
ECHO %0 > HGSYST$$.TIT
ECHO HPI >> HGSYST$$.TIT
ECHO %HGSYSTEM%\DICT.HPD >> HGSYST$$.TIT
REM Input: HGSYST$$.TIT, %HGSYSTEM%\DICT.HPD, %0.TMI
REM Output: %0.HPI, %0.HPF, %0.HPU
REM         %0.TME (in case of errors)
%HGSYSTEM%\FFMAIN 
REM
REM ----erase temporary files
REM
IF EXIST HGSYST$$.TIT DEL HGSYST$$.TIT
IF EXIST %0.TMI DEL %0.TMI > NUL
IF EXIST %0.HPF DEL %0.HPF > NUL
REM
REM ----check if error file exists
REM
IF EXIST %0.HPE GOTO HPERR
IF NOT EXIST %0.TME GOTO FFOK
ECHO Input errors exist - check input file - program terminated
IF EXIST %0.TME DEL %0.TME > NUL
IF EXIST %0.HPU DEL %0.HPU > NUL
GOTO EXIT
:FFOK
REM
REM ----check if unformatted input file exists; if not, terminate
REM
IF EXIST %0.HPU GOTO UNFOK
ECHO Unformatted input file not available - program terminated
GOTO EXIT
:UNFOK
ECHO HFPLUME calculations are being performed
REM
REM ---- copy name of analysis to file (to set file names in HPMAIN)
REM
ECHO %0 > HGSYST$$.TIT
ECHO HPI >> HGSYST$$.TIT
ECHO %HGSYSTEM%\DICT.HPD >> HGSYST$$.TIT
REM Input: HGSYST$$.TIT, %0.HPU
REM Output: %0.HPR, %0.HP1, %0.HP2, %0.HPZ, %0.HPM
REM         %0.HSL, %0.HTL, %0.PGL (if links successful)
REM         %0.HPE, %0.HPN (in case of errors)
REM         %0.HPW (in case of warnings)

%HGSYSTEM%\HPMAIN 

REM run77 hpmain /break

REM
REM ----erase temporary files
REM
IF EXIST HGSYST$$.TIT DEL HGSYST$$.TIT
IF EXIST %0.HPU DEL %0.HPU
IF EXIST %0.HPE GOTO HPERR
GOTO HPCONT
:HPERR
ECHO ***** ERRORS ***** have been found during HFPLUME run
ECHO See the file %0.HPE for list of errors
ECHO HP-----------------------------------------------------------
:HPCONT
rem IF EXIST %0.HP1 DEL %0.HP1 > NUL
rem IF EXIST %0.HP2 DEL %0.HP2 > NUL
rem IF EXIST %0.HPZ DEL %0.HPZ > NUL
rem IF EXIST %0.HPD DEL %0.HPD > NUL
rem IF EXIST %0.HPN DEL %0.HPN > NUL
ECHO End of HFPLUME
IF EXIST %0.HPR ECHO Output in file %0.HPR
IF EXIST %0.HP1 ECHO Assist-data for manual matching to PGPLUME in file %0.HP1
IF EXIST %0.HP2 ECHO Assist-data for manual matching to HEGADAS-S in file %0.HP2
IF EXIST %0.APZ ECHO Detailed info on matching criteria values in file %0.HPZ
IF EXIST %0.PGL ECHO PGPLUME input data in file %0.PGL
IF EXIST %0.HSL ECHO HEGADAS-S input data in file %0.HSL
IF EXIST %0.HTL ECHO HEGADAS-T input data in file %0.HTL
IF EXIST %0.HPM ECHO Monitor messages in file %0.HPM
IF EXIST %0.HPN ECHO Numerical diagnostics in file %0.HPN
IF EXIST %0.HPW ECHO ***** Warning ***** messages in file %0.HPW
:EXIT
ECHO HP============== End   of HFPLUME batch file ================
