@ECHO OFF
ECHO HL============== Start of HFSPILL batch file ================
REM Modified by Steve Richardson     12/96
REM
REM Set the environment variable to the shared drive

REM
REM ----check at least one input argument; if not, terminate
REM
IF NOT %1.==. GOTO ARGOK
ECHO   Run model HFSPILL with 1 to n input files as required.
ECHO   Parameters should be entered as follows :-
ECHO    1 to n-1  input files to be concatenated, with file names
ECHO              of the form FILENAME.EXT
ECHO    n         identifier for this run, with file name
ECHO              of the form FILENAME     (N.B. NO EXTENSION)
ECHO              (system assumes extension .HLI, and uses/creates
ECHO              (files with this name and various extensions).
ECHO    if n=1    the file must already exist with the extension .HLI,
ECHO              but the extension must not be included.
ECHO    if n=2    the first file must already exist with its specified
ECHO              extension, and the file will be copied to the
ECHO              second file (system assumes extension .HLI).
ECHO    else      n-1 files must already exist with their specified
ECHO              extensions, and they will be concatenated and copied
ECHO              to the n'th file (system assumes extension .HLI).
ECHO   The file SKELETON.HLI can be copied from %HGSYSTEM%\STINPUT as a
ECHO   template for an input data file *.HLI.
GOTO EXIT
:ARGOK
REM
REM ----SHIFT eliminates first argument and moves all others down one
REM
SHIFT
REM
REM ----check if only one input argument specified
REM
IF NOT %1.==. GOTO NUMARGS
REM
REM ----one argument; check if the input file exists
REM ----if yes, check data dictionary; if not, terminate
REM
IF EXIST %0.HLI GOTO CHECKDD
ECHO HFSPILL - Input file %0.HLI does not exist - program terminated
GOTO EXIT
:NUMARGS
REM
REM ----check if only two input arguments specified
REM
IF NOT %2.==. GOTO CONCAT
REM
REM ----two arguments; check if first file exists; if not, terminate
REM
IF EXIST %0 GOTO COPY1
ECHO HFSPILL - Input file %0 does not exist - program terminated
GOTO EXIT
:COPY1
REM
REM ----copy file, do not concatenate, check data dictionary
REM
copy /b %0 %1.HLI > NUL:
SHIFT
GOTO CHECKDD
:CONCAT
REM
REM ----more than two arguments; create CONCAT key in temporary file
REM
ECHO = CONCAT == > $CONCAT$.HLI
:CHECKN
REM
REM ----check if input file exists; if not, terminate
REM
IF EXIST %0 GOTO COPYN
ECHO HFSPILL - Input file %0 does not exist - program terminated
IF EXIST $CONCAT$.HLI DEL $CONCAT$.HLI
GOTO EXIT
:COPYN
REM
REM ----copy input file at end of temporary file
REM
copy /b $CONCAT$.HLI+%0 > NUL:
REM
REM ----is there another file to concatenate?
REM
SHIFT
IF NOT %1.==. GOTO CHECKN
REM
REM ----no more files to concatenate; copy to final file
REM
copy /b $CONCAT$.HLI %0.HLI > NUL:
IF EXIST $CONCAT$.HLI DEL $CONCAT$.HLI
:CHECKDD
REM
REM ----check if preprocessed data dictionary exists; if not, terminate
REM
IF EXIST %HGSYSTEM%\DICT.HLD GOTO DICTOK
ECHO DICT.HLD data dictionary does not exist - program terminated
GOTO EXIT
:DICTOK
REM
REM ----delete all files which might be generated during HFSPILL run
REM
IF EXIST %0.HLE DEL %0.HLE
IF EXIST %0.HLR DEL %0.HLR
IF EXIST %0.HLM DEL %0.HLM
IF EXIST %0.HLN DEL %0.HLN
IF EXIST %0.HPL DEL %0.HPL
IF EXIST %0.LPL DEL %0.LPL
REM
ECHO Input validation is in progress
REM
REM ----make a copy of the free-format input file
REM
copy /b %0.HLI %0.TMI >NUL:
REM
REM ---- copy name of analysis to file (to set file names in FFMAIN)
REM
ECHO %0 > HGSYST$$.TIT
ECHO HLI >> HGSYST$$.TIT
ECHO %HGSYSTEM%\DICT.HLD >> HGSYST$$.TIT
REM Input: HGSYST$$.TIT, %HGSYSTEM%\DICT.HLD, %0.TMI
REM Output: %0.HLI, %0.HLF, %0.HLU
REM         %0.TME (in case of errors)
%HGSYSTEM%\FFMAIN
REM
REM ----erase temporary files
REM
IF EXIST HGSYST$$.TIT DEL HGSYST$$.TIT
IF EXIST %0.TMI DEL %0.TMI
IF EXIST %0.HLF DEL %0.HLF
REM
REM ----check if error file exists
REM
IF EXIST %0.HLE GOTO HLERR
IF NOT EXIST %0.TME GOTO FFOK
ECHO Input errors exist - check input file - program terminated
IF EXIST %0.TME DEL %0.TME
IF EXIST %0.HLU DEL %0.HLU
GOTO EXIT
:FFOK
REM
REM ----check if unformatted input file exists; if not, terminate
REM
IF EXIST %0.HLU GOTO UNFOK
ECHO Unformatted input file not available - program terminated
GOTO EXIT
:UNFOK
ECHO HFSPILL calculations are being performed
REM
REM ---- copy name of analysis to file (to set file names in HLMAIN)
REM
ECHO %0 > HGSYST$$.TIT
ECHO HLI >> HGSYST$$.TIT
ECHO %HGSYSTEM%\DICT.HLD >> HGSYST$$.TIT
REM Input: HGSYST$$.TIT, %0.HLU
REM Output: %0.HLR, %0.HLM
REM         %0.LPL, %0.HPL (if links successful)
REM         %0.HLE, %0.HLN (in case of errors)
%HGSYSTEM%\HLMAIN 
REM
REM ----erase temporary files
REM
IF EXIST HGSYST$$.TIT DEL HGSYST$$.TIT
IF EXIST %0.HLU DEL %0.HLU
IF EXIST %0.HLE GOTO HLERR
IF EXIST %0.HLN DEL %0.HLN
GOTO HLCONT
:HLERR
ECHO ERRORS have been found during HFSPILL run
ECHO See the file %0.HLE for list of errors
ECHO HL-----------------------------------------------------------
:HLCONT
ECHO End of HFSPILL
IF EXIST %0.HLR ECHO Output in file %0.HLR
IF EXIST %0.HPL ECHO HFPLUME input data in file %0.HPL
IF EXIST %0.LPL ECHO LPOOL input data in file %0.LPL
IF EXIST %0.HLM ECHO Monitor messages in file %0.HLM
IF EXIST %0.HLN ECHO Numerical diagnostics in file %0.HLN
:EXIT
ECHO HL============== End   of HFSPILL batch file ================
