@ECHO OFF
ECHO PG============== Start of PGPLUME batch file ================
REM Modified by Steve Richardson     12/96
REM
REM Set the environment variable to the shared drive

REM
REM ----check at least one input argument; if not, terminate
REM
IF NOT %1.==. GOTO ARGOK
ECHO   Run model PGPLUME with 1 to n input files as required.
ECHO   Parameters should be entered as follows :-
ECHO    1 to n-1  input files to be concatenated, with file names
ECHO              of the form FILENAME.EXT
ECHO    n         identifier for this run, with file name
ECHO              of the form FILENAME     (N.B. NO EXTENSION)
ECHO              (system assumes extension .PGI, and uses/creates
ECHO              (files with this name and various extensions).
ECHO    if n=1    the file must already exist with the extension .PGI,
ECHO              but the extension must not be included.
ECHO    if n=2    the first file must already exist with its specified
ECHO              extension, and the file will be copied to the
ECHO              second file (system assumes extension .PGI).
ECHO    else      n-1 files must already exist with their specified
ECHO              extensions, and they will be concatenated and copied
ECHO              to the n'th file (system assumes extension .PGI).
ECHO   The file SKELETON.PGI can be copied from %HGSYSTEM%\STINPUT as a
ECHO   template for an input data file *.PGI.
GOTO EXIT
:ARGOK
REM
REM ----SHIFT eliminates first argument and moves all others down one
REM
SHIFT
REM
REM ----check if only one input argument specified
REM
IF NOT %1.==. GOTO NUMARGS
REM
REM ----one argument; check if the input file exists
REM ----if yes, check data dictionary; if not, terminate
REM
IF EXIST %0.PGI GOTO CHECKDD
ECHO PGPLUME - Input file %0.PGI does not exist - program terminated
GOTO EXIT
:NUMARGS
REM
REM ----check if only two input arguments specified
REM
IF NOT %2.==. GOTO CONCAT
REM
REM ----two arguments; check if first file exists; if not, terminate
REM
IF EXIST %0 GOTO COPY1
ECHO PGPLUME - Input file %0 does not exist - program terminated
GOTO EXIT
:COPY1
REM
REM ----copy file, do not concatenate, check data dictionary
REM
copy /b %0 %1.PGI > NUL:
SHIFT
GOTO CHECKDD
:CONCAT
REM
REM ----more than two arguments; create CONCAT key in temporary file
REM
ECHO = CONCAT == > $CONCAT$.PGI
:CHECKN
REM
REM ----check if input file exists; if not, terminate
REM
IF EXIST %0 GOTO COPYN
ECHO PGPLUME - Input file %0 does not exist - program terminated
IF EXIST $CONCAT$.PGI DEL $CONCAT$.PGI
GOTO EXIT
:COPYN
REM
REM ----copy input file at end of temporary file
REM
copy /b $CONCAT$.PGI+%0 > NUL:
REM
REM ----is there another file to concatenate?
REM
SHIFT
IF NOT %1.==. GOTO CHECKN
REM
REM ----no more files to concatenate; copy to final file
REM
copy /b $CONCAT$.PGI %0.PGI > NUL:
IF EXIST $CONCAT$.PGI DEL $CONCAT$.PGI
:CHECKDD
REM
REM ----check if preprocessed data dictionary exists; if not, terminate
REM
IF EXIST %HGSYSTEM%\DICT.PGD GOTO DICTOK
ECHO DICT.PGD data dictionary does not exist - program terminated
GOTO EXIT
:DICTOK
REM
REM ----delete all files which might be generated during PGPLUME run
REM
IF EXIST %0.PGE DEL %0.PGE
IF EXIST %0.PGR DEL %0.PGR
IF EXIST %0.PG1 DEL %0.PG1
IF EXIST %0.PGM DEL %0.PGM
IF EXIST %0.PGN DEL %0.PGN
REM
ECHO Input validation is in progress
REM
REM ----make a copy of the free-format input file
REM
copy /b %0.PGI %0.TMI >NUL:
REM
REM ---- copy name of analysis to file (to set file names in FFMAIN)
REM
ECHO %0 > HGSYST$$.TIT
ECHO PGI >> HGSYST$$.TIT
ECHO %HGSYSTEM%\DICT.PGD >> HGSYST$$.TIT
REM Input: HGSYST$$.TIT, %HGSYSTEM%\DICT.PGD, %0.TMI
REM Output: %0.PGI, %0.PGF, %0.PGU
REM         %0.TME (in case of errors)
%HGSYSTEM%\FFMAIN 
REM
REM ----erase temporary files
REM
IF EXIST HGSYST$$.TIT DEL HGSYST$$.TIT
IF EXIST %0.TMI DEL %0.TMI
IF EXIST %0.PGF DEL %0.PGF
REM
REM ----check if error file exists
REM
IF EXIST %0.PGE GOTO PGERR
IF NOT EXIST %0.TME GOTO FFOK
ECHO Input errors exist - check input file - program terminated
IF EXIST %0.TME DEL %0.TME
IF EXIST %0.PGU DEL %0.PGU
GOTO EXIT
:FFOK
REM
REM ----check if unformatted input file exists; if not, terminate
REM
IF EXIST %0.PGU GOTO UNFOK
ECHO Unformatted input file not available - program terminated
GOTO EXIT
:UNFOK
ECHO PGPLUME calculations are being performed
REM
REM ---- copy name of analysis to file (to set file names in PGMAIN)
REM
ECHO %0 > HGSYST$$.TIT
ECHO PGI >> HGSYST$$.TIT
ECHO %HGSYSTEM%\DICT.PGD >> HGSYST$$.TIT
REM Input: HGSYST$$.TIT, %0.PGU
REM Output: %0.PGR, %0.PG1, %0.PGM
REM         %0.PGE, %0.PGN (in case of errors)
%HGSYSTEM%\PGMAIN
REM
REM ----erase temporary files
REM
IF EXIST HGSYST$$.TIT DEL HGSYST$$.TIT
IF EXIST %0.PGU DEL %0.PGU
IF EXIST %0.PGE GOTO PGERR
IF EXIST %0.PGN DEL %0.PGN
GOTO PGCONT
:PGERR
ECHO ERRORS have been found during PGPLUME run
ECHO See the file %0.PGE for list of errors
ECHO PG-----------------------------------------------------------
:PGCONT
ECHO End of PGPLUME
IF EXIST %0.PGR ECHO Output in file %0.PGR
IF EXIST %0.PG1 ECHO Profile output in file %0.PG1
IF EXIST %0.PGM ECHO Monitor messages in file %0.PGM
IF EXIST %0.PGN ECHO Numerical diagnostics in file %0.PGN
:EXIT
ECHO PG============== End   of PGPLUME batch file ================
