@ECHO OFF
REM  Last modified 29-01-1997 by F.J. Rees (SRTCT)
REM  
ECHO HW============== Start of HEGLOW batch file ================
REM
REM ----check at least one input argument; if not, terminate
REM
IF NOT %1.==. GOTO ARGOK
ECHO   Run model HEGLOW with 1 to n input files as required.
ECHO   Parameters should be entered as follows :-
ECHO    1 to n-1  input files to be concatenated, with file names
ECHO              of the form FILENAME.EXT
ECHO    n         identifier for this run, with file name
ECHO              of the form FILENAME     (N.B. NO EXTENSION)
ECHO              (system assumes extension .HWI, and uses/creates
ECHO              (files with this name and various extensions).
ECHO    if n=1    the file must already exist with the extension .HWI,
ECHO              but the extension must not be included.
ECHO    if n=2    the first file must already exist with its specified
ECHO              extension, and the file will be copied to the
ECHO              second file (system assumes extension .HWI).
ECHO    else      n-1 files must already exist with their specified
ECHO              extensions, and they will be concatenated and copied
ECHO              to the n'th file (system assumes extension .HWI).
ECHO   One of the two basic HEGLOW input files STANDNO.HWI, and
ECHO   STANDHF.HWI can be copied from
ECHO   %HGSYSTEM%\STINPUT as a template for an input data file *.HWI.
GOTO EXIT
:ARGOK
REM
REM ----SHIFT eliminates first argument and moves all others down one
REM
SHIFT
REM
REM ----check if only one input argument specified
REM
IF NOT %1.==. GOTO NUMARGS
REM
REM ----one argument; check if the input file exists
REM ----if yes, check data dictionary; if not, terminate
REM
IF EXIST %0.HWI GOTO CHECKDD
ECHO HEGLOW - Input file %0.HWI does not exist - program terminated
GOTO EXIT
:NUMARGS
REM
REM ----check if only two input arguments specified
REM
IF NOT %2.==. GOTO CONCAT
REM
REM ----two arguments; check if first file exists; if not, terminate
REM
IF EXIST %0 GOTO COPY1
ECHO HEGLOW - Input file %0 does not exist - program terminated
GOTO EXIT
:COPY1
REM
REM ----copy file, do not concatenate, check data dictionary
REM
copy /b %0 %1.HWI > NUL:
SHIFT
GOTO CHECKDD
:CONCAT
REM
REM ----more than two arguments; create CONCAT key in temporary file
REM
ECHO = CONCAT == > $CONCAT$.HWI
:CHECKN
REM
REM ----check if input file exists; if not, terminate
REM
IF EXIST %0 GOTO COPYN
ECHO HEGLOW - Input file %0 does not exist - program terminated
IF EXIST $CONCAT$.HWI DEL $CONCAT$.HWI
GOTO EXIT
:COPYN
REM
REM ----copy input file at end of temporary file
REM
copy /b $CONCAT$.HWI+%0 > NUL:
REM
REM ----is there another file to concatenate?
REM
SHIFT
IF NOT %1.==. GOTO CHECKN
REM
REM ----no more files to concatenate; copy to final file
REM
copy /b $CONCAT$.HWI %0.HWI > NUL:
IF EXIST $CONCAT$.HWI DEL $CONCAT$.HWI
:CHECKDD
REM
REM ----check if preprocessed data dictionary exists; if not, terminate
REM
IF EXIST %HGSYSTEM%\DICT.HWD GOTO DICTOK
ECHO DICT.HWD data dictionary does not exist - program terminated
GOTO EXIT
:DICTOK
REM
REM ----delete all files which might be generated during HEGLOW run
REM
IF EXIST %0.HWE DEL %0.HWE >NUL:
IF EXIST %0.HWR DEL %0.HWR >NUL:
IF EXIST %0.HWO DEL %0.HWO >NUL:
IF EXIST %0.HTL DEL %0.HTL >NUL:
IF EXIST %0.MMO DEL %0.MMO >NUL:
REM
REM ----make a copy of the free-format input file
REM
copy /b %0.HWI %0.TMI > NUL
REM
REM ---- copy name of analysis to file (to set file names in FFMAIN)
REM
ECHO %0 > HGSYST$$.TIT
ECHO HWI >> HGSYST$$.TIT
ECHO %HGSYSTEM%\DICT.HWD >> HGSYST$$.TIT
REM Input: HGSYST$$.TIT, %HGSYSTEM%\DICT.HWD, %0.TMI
REM Output: %0.HWI, %0.HWF, %0.HWU
REM         %0.TME (in case of errors)
%HGSYSTEM%\FFMAIN
REM
REM ----erase temporary files
REM
IF EXIST HGSYST$$.TIT DEL HGSYST$$.TIT
IF EXIST %0.TMI DEL %0.TMI
IF EXIST %0.HWF DEL %0.HWF
REM
REM ----erase temporary files
REM
IF EXIST HGSYST$$.TIT DEL HGSYST$$.TIT
IF EXIST %0.TMI DEL %0.TMI > NUL
IF EXIST %0.HWF DEL %0.HWF > NUL
REM
REM ----check if error file exists
REM
IF EXIST %0.HWE GOTO HWERR
IF NOT EXIST %0.TME GOTO FFOK
ECHO Input errors exist - check input file - program terminated
IF EXIST %0.TME DEL %0.TME > NUL
IF EXIST %0.HWU DEL %0.HWU > NUL
GOTO EXIT
:FFOK
REM
REM ----check if unformatted input file exists; if not, terminate
REM
IF EXIST %0.HWU GOTO UNFOK
ECHO Unformatted input file not available - program terminated
GOTO EXIT
:UNFOK
ECHO HEGLOW calculations are being performed
REM
REM ---- copy name of analysis to file (to set file names in HWMAIN)
REM
ECHO %0 > HGSYST$$.TIT
ECHO HWI >> HGSYST$$.TIT
ECHO %HGSYSTEM%\DICT.HWD >> HGSYST$$.TIT
REM Input: HGSYST$$.TIT, %0.HWU
REM Output: %0.HWR , %0.HWO etc

%HGSYSTEM%\HWMAIN 

rem RUN77 D:\HEGLOW\HWMAIN /BREAK

REM
REM ----erase temporary files
REM
IF EXIST HGSYST$$.TIT DEL HGSYST$$.TIT
IF EXIST %0.HWU DEL %0.HWU
IF EXIST %0.HWE GOTO HWERR
GOTO HWCONT
:HWERR
ECHO ***** ERRORS ***** have been found during HEGLOW run
ECHO See the file %0.HWE for list of errors
ECHO HW--------------------------------------------------------
:HWCONT
ECHO End of HEGLOW
IF EXIST %0.HWR ECHO Output in report file %0.HWR
IF EXIST %0.HWO ECHO Observer data for HEGADAS-T in (formatted) file %0.HWO
IF EXIST %0.HTL ECHO HEGADAS-T input data in link file %0.HTL
IF EXIST %0.MMO ECHO Info on MMES options in file %0.MMO
:EXIT
ECHO HW============== End of HEGLOW batch file ================
