@ECHO OFF
ECHO PR============== Start of PROFILE batch file ================
REM
REM ----check at least one input argument; if not, terminate
REM
IF NOT %1.==. GOTO ARGOK
ECHO   Run program PROFILE with 1 to n input files as required.
ECHO   Parameters should be entered as follows :-
ECHO    1 to n-1  input files to be concatenated, with file names
ECHO              of the form FILENAME.EXT
ECHO    n         identifier for this run, with file name
ECHO              of the form FILENAME     (N.B. NO EXTENSION)
ECHO              (system assumes extension .PRI, and uses/creates
ECHO              (files with this name and various extensions).
ECHO    if n=1    the file must already exist with the extension .PRI,
ECHO              but the extension must not be included.
ECHO    if n=2    the first file must already exist with its specified
ECHO              extension, and the file will be copied to the
ECHO              second file (system assumes extension .PRI).
ECHO    else      n-1 files must already exist with their specified
ECHO              extensions, and they will be concatenated and copied
ECHO              to the n'th file (system assumes extension .PRI).
ECHO   The file SKELETON.PRI can be copied from %HGSYSTEM%\STINPUT as a
ECHO   template for an input data file *.PRI.
GOTO EXIT
:ARGOK
REM
REM ----SHIFT eliminates first argument and moves all others down one
REM
SHIFT
REM
REM ----check if only one input argument specified
REM
IF NOT %1.==. GOTO NUMARGS
REM
REM ----one argument; check if the input file exists
REM ----if yes, check data dictionary; if not, terminate
REM
IF EXIST %0.PRI GOTO CHECKDD
ECHO PROFILE - Input file %0.PRI does not exist - program terminated
GOTO EXIT
:NUMARGS
REM
REM ----check if only two input arguments specified
REM
IF NOT %2.==. GOTO CONCAT
REM
REM ----two arguments; check if first file exists; if not, terminate
REM
IF EXIST %0 GOTO COPY1
ECHO PROFILE - Input file %0 does not exist - program terminated
GOTO EXIT
:COPY1
REM
REM ----copy file, do not concatenate, check data dictionary
REM
copy /b %0 %1.PRI > NUL:
SHIFT
GOTO CHECKDD
:CONCAT
REM
REM ----more than two arguments; create CONCAT key in temporary file
REM
ECHO = CONCAT == > $CONCAT$.PRI
:CHECKN
REM
REM ----check if input file exists; if not, terminate
REM
IF EXIST %0 GOTO COPYN
ECHO PROFILE - Input file %0 does not exist - program terminated
IF EXIST $CONCAT$.PRI DEL $CONCAT$.PRI
GOTO EXIT
:COPYN
REM
REM ----copy input file at end of temporary file
REM
copy /b $CONCAT$.PRI+%0 > NUL:
REM
REM ----is there another file to concatenate?
REM
SHIFT
IF NOT %1.==. GOTO CHECKN
REM
REM ----no more files to concatenate; copy to final file
REM
copy /b $CONCAT$.PRI %0.PRI > NUL:
IF EXIST $CONCAT$.PRI DEL $CONCAT$.PRI
:CHECKDD
REM
REM ----check if preprocessed data dictionary exists; if not, terminate
REM
IF EXIST %HGSYSTEM%\DICT.PRD GOTO DICTOK
ECHO DICT.PRD data dictionary does not exist - program terminated
GOTO EXIT
:DICTOK
REM
REM ----delete all files which might be generated during PROFILE run
REM
IF EXIST %0.PRE DEL %0.PRE
IF EXIST %0.PRR DEL %0.PRR
IF EXIST %0.PRH DEL %0.PRH
IF EXIST %0.PRV DEL %0.PRV
REM
ECHO Input validation is in progress
REM
REM ----make a copy of the free-format input file
REM
copy /b %0.PRI %0.TMI >NUL:
REM
REM ---- copy name of analysis to file (to set file names in FFMAIN)
REM
ECHO %0 > HGSYST$$.TIT
ECHO PRI >> HGSYST$$.TIT
ECHO %HGSYSTEM%\DICT.PRD >> HGSYST$$.TIT
REM Input: HGSYST$$.TIT, %HGSYSTEM%\DICT.PRD, %0.TMI
REM Output: %0.PRI, %0.PRF, %0.PRU
REM         %0.TME (in case of errors)
%HGSYSTEM%\FFMAIN 
REM
REM ----erase temporary files
REM
IF EXIST HGSYST$$.TIT DEL HGSYST$$.TIT
IF EXIST %0.TMI DEL %0.TMI
IF EXIST %0.PRF DEL %0.PRF
REM
REM ----check if error file exists
REM
IF EXIST %0.PRE GOTO PRERR
IF NOT EXIST %0.TME GOTO FFOK
ECHO Input errors exist - check input file - program terminated
IF EXIST %0.TME DEL %0.TME
IF EXIST %0.PRU DEL %0.PRU
GOTO EXIT
:FFOK
REM
REM ----check if unformatted input file exists; if not, terminate
REM
IF EXIST %0.PRU GOTO UNFOK
ECHO Unformatted input file not available - program terminated
GOTO EXIT
:UNFOK
ECHO PROFILE operations are being performed
REM
REM ---- copy name of analysis to file (to set file names in PRMAIN)
REM
ECHO %0 > HGSYST$$.TIT
REM Input: HGSYST$$.TIT, %0.PRU
REM Output: %0.PRR
REM         %0.PRE (in case of errors)
%HGSYSTEM%\PRMAINHF 
REM
REM ----erase temporary files
REM
IF EXIST HGSYST$$.TIT DEL HGSYST$$.TIT
IF EXIST %0.PRU DEL %0.PRU
IF EXIST %0.PRE GOTO PRERR
GOTO PRCONT
:PRERR
ECHO ERRORS have been found during PROFILE run
ECHO See the file %0.PRE for list of errors
ECHO PR-----------------------------------------------------------
:PRCONT
ECHO End of PROFILE
IF EXIST %0.PRR ECHO %0.PRR contains centreline and ground-level concentrations.
IF EXIST %0.PRH ECHO %0.PRH contains horizontal contours at the preselected height.
IF EXIST %0.PRV ECHO %0.PRV contains vertical contours in the plane y=0.
:EXIT
ECHO PR============== End   of PROFILE batch file ================
